@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 #
 # Retrieve list of links from a shared-folder (sharing site) url
-# Copyright (c) 2010-2015 Plowshare team
+# Copyright (c) 2010-2016 Plowshare team
 #
 # This file is part of Plowshare.
 #
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Plowshare.  If not, see <http://www.gnu.org/licenses/>.
 
-declare -r VERSION='v2.1.3 (2016-03-24)'
+declare -r VERSION='v2.1.5 (2016-09-17)'
 
 declare -r EARLY_OPTIONS="
 HELP,h,help,,Show help info and exit
@@ -26,7 +26,8 @@ HELPFUL,H,longhelp,,Exhaustive help info (with modules command-line options)
 GETVERSION,,version,,Output plowlist version information and exit
 ALLMODULES,,modules,,Output available modules (one per line) and exit. Useful for wrappers.
 EXT_PLOWSHARERC,,plowsharerc,f=FILE,Force using an alternate configuration file (overrides default search path)
-NO_PLOWSHARERC,,no-plowsharerc,,Do not use any plowshare.conf configuration file"
+NO_PLOWSHARERC,,no-plowsharerc,,Do not use any plowshare.conf configuration file
+NO_COLOR,,no-color,,Disables log notice & log error output coloring"
 
 declare -r MAIN_OPTIONS="
 VERBOSE,v,verbose,c|0|1|2|3|4=LEVEL,Verbosity level: 0=none, 1=err, 2=notice (default), 3=dbg, 4=report
@@ -34,7 +35,7 @@ QUIET,q,quiet,,Alias for -v0
 INTERFACE,i,interface,s=IFACE,Force IFACE network interface
 RECURSE,R,recursive,,Recurse into sub folders
 PRINTF_FORMAT,,printf,s=FORMAT,Print results in a given format (for each link). Default is \"%F%u%n\".
-NO_COLOR,,no-color,,Disables log notice & log error output coloring
+TIMEOUT,t,timeout,n=SECS,Timeout after SECS seconds of waits. May be useful for multiupload hosters.
 NO_MODULE_FALLBACK,,fallback,,If no module is found for link, simply list all URLs contained in page
 EXT_CURLRC,,curlrc,f=FILE,Force using an alternate curl configuration file (overrides ~/.curlrc)
 NO_CURLRC,,no-curlrc,,Do not use curlrc config file"
@@ -197,7 +198,14 @@ fi
 
 # Get configuration file options. Command-line is partially parsed.
 test -z "$NO_PLOWSHARERC" && \
-    process_configfile_options '[Pp]lowlist' "$MAIN_OPTIONS" "$EXT_PLOWSHARERC"
+    process_configfile_options '[Pp]lowlist' "${MAIN_OPTIONS}
+NO_COLOR,,no-color,,x" "$EXT_PLOWSHARERC"
+
+if [ -n "$NO_COLOR" ]; then
+    unset COLOR
+else
+    declare -r COLOR=yes
+fi
 
 declare -a COMMAND_LINE_MODULE_OPTS COMMAND_LINE_ARGS RETVALS
 COMMAND_LINE_ARGS=("${UNUSED_ARGS[@]}")
@@ -213,12 +221,6 @@ elif [ -z "$VERBOSE" ]; then
     declare -r VERBOSE=2
 fi
 
-if [ -n "$NO_COLOR" ]; then
-    unset COLOR
-else
-    declare -r COLOR=yes
-fi
-
 if [ $# -lt 1 ]; then
     log_error 'plowlist: no folder URL specified!'
     log_error "plowlist: try \`plowlist --help' for more information."
@@ -301,30 +303,44 @@ for URL in "${COMMAND_LINE_ARGS[@]}"; do
 
     FUNCTION=${MODULE}_list
     log_notice "Retrieving list ($MODULE): $URL"
+    timeout_init $TIMEOUT
 
     if ! module_config_has_subfolders "$MODULE" && test -n "$RECURSE"; then
         log_notice 'recursive flag has no sense here, ignoring'
     fi
 
-    ${MODULE}_vars_set
-    $FUNCTION "${UNUSED_OPTIONS[@]}" "$URL" "$RECURSE" | \
-        pretty_print "${PRINTF_FORMAT:-%F%u%n}" "$MODULE" || LRETVAL=$?
-    ${MODULE}_vars_unset
+    AWAIT=3
+    while :; do
+        LRETVAL=0
+
+        ${MODULE}_vars_set
+        $FUNCTION "${UNUSED_OPTIONS[@]}" "$URL" "$RECURSE" | \
+            pretty_print "${PRINTF_FORMAT:-%F%u%n}" "$MODULE" || LRETVAL=$?
+        ${MODULE}_vars_unset
+
+        if [ $LRETVAL -eq 0 ]; then
+            : # everything went fine
+        elif [ $LRETVAL -eq $ERR_LINK_DEAD ]; then
+            log_error 'Non existing or empty folder'
+            [ -z "$RECURSE" -a -z "$NO_MODULE_FALLBACK" ] && \
+                module_config_has_subfolders "$MODULE" && \
+                log_notice 'Try adding -R/--recursive option to look into sub folders'
+        elif [ $LRETVAL -eq $ERR_LINK_PASSWORD_REQUIRED ]; then
+            log_error 'You must provide a valid password'
+        elif [ $LRETVAL -eq $ERR_LINK_TEMP_UNAVAILABLE ]; then
+            if [[ $TIMEOUT -gt 0 ]]; then
+                log_notice 'Links are temporarily unavailable. Exponentially wait.'
+                wait $(( (2 ** AWAIT++ - 1) / 2)) || { LRETVAL=$?; break; }
+                continue
+            else
+                log_error 'Links are temporarily unavailable. Maybe uploads are still being processed.'
+            fi
+        else
+            log_error "Failed inside ${FUNCTION}() [$LRETVAL]"
+        fi
+        break
+    done
 
-    if [ $LRETVAL -eq 0 ]; then
-        : # everything went fine
-    elif [ $LRETVAL -eq $ERR_LINK_DEAD ]; then
-        log_error 'Non existing or empty folder'
-        [ -z "$RECURSE" -a -z "$NO_MODULE_FALLBACK" ] && \
-            module_config_has_subfolders "$MODULE" && \
-            log_notice 'Try adding -R/--recursive option to look into sub folders'
-    elif [ $LRETVAL -eq $ERR_LINK_PASSWORD_REQUIRED ]; then
-        log_error 'You must provide a valid password'
-    elif [ $LRETVAL -eq $ERR_LINK_TEMP_UNAVAILABLE ]; then
-        log_error 'Links are temporarily unavailable. Maybe uploads are still being processed'
-    else
-        log_error "Failed inside ${FUNCTION}() [$LRETVAL]"
-    fi
     RETVALS=(${RETVALS[@]} $LRETVAL)
 done
 
