@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 #
 # Easy module management (installation/update) utility
-# Copyright (c) 2015 Plowshare team
+# Copyright (c) 2015-2016 Plowshare team
 #
 # This file is part of Plowshare.
 #
@@ -18,22 +18,15 @@
 # You should have received a copy of the GNU General Public License
 # along with Plowshare.  If not, see <http://www.gnu.org/licenses/>.
 
-declare -r VERSION='v2.1.3 (2016-03-24)'
+declare -r VERSION='v2.1.5 (2016-09-17)'
 
 # Default repository source
 declare -r LEGACY_MODULES='https://github.com/mcrapet/plowshare-modules-legacy.git'
 
-declare -r MAIN_OPTIONS="
-HELP,h,help,,Show help info and exit
-GETVERSION,,version,,Output plowmod version information and exit
-VERBOSE,v,verbose,c|0|1|2|3|4=LEVEL,Verbosity level: 0=none, 1=err, 2=notice (default), 3=dbg, 4=report
-QUIET,q,quiet,,Alias for -v0
-NO_COLOR,,no-color,,Disables log notice & log error output coloring
-MOD_DIR,,modules-directory,D=DIR,For maintainers only. Set modules directory (default is ~/.config/plowshare/modules.d)"
-declare -r ACTION_OPTIONS="
+declare -r ACTION_OPTIONS='
 DO_INSTALL,i,install,,Install one or several given repositories to modules directory
 DO_STATUS,s,status,,Print current modules configuration
-DO_UPDATE,u,update,,Update modules directory (requires git)"
+DO_UPDATE,u,update,,Update modules directory (requires git)'
 
 # This function is duplicated from download.sh
 absolute_path() {
@@ -69,7 +62,7 @@ EOH
     print_options "$ACTION_OPTIONS"
     cat <<EOH
 
-For install, if no source repository is specified use:
+For install, if no source repository is specified, it uses:
 $LEGACY_MODULES
 
 Available options:
@@ -103,8 +96,14 @@ mod_install() {
             log_notice 'WARNING: directory already exists! Do a git pull.'
             git -C "$L" pull --quiet
         else
-            log_error 'ERROR: directory exists but it does not appear to be a git repository, abort'
-            RET=$ERR_FATAL
+            # Check for empty directory (find -empty)
+            if [[ ! $(ls -1A "$L" 2>/dev/null) ]] && [ -w "$L" ]; then
+                # Be stupid for now and git clone. See --depth later.
+                git clone --quiet "$R" "$L"
+            else
+                log_error 'ERROR: directory exists but it does not appear to be a git repository, abort'
+                RET=$ERR_FATAL
+            fi
         fi
     else
         # Be stupid for now and git clone. See --depth later.
@@ -167,7 +166,7 @@ mod_status() {
     fi
 
     # Check for first install
-    N=$(grep '^[^#]' "${SRCS[@]/%/\/config}" | wc -l)
+    N=$(grep '^[^#]' "${SRCS[@]/%//config}" | wc -l)
     if (( N == 0 )); then
         log_error \
 "-------------------------------------------------------------------------------
@@ -237,6 +236,14 @@ set -e # enable exit checking
 
 source "$LIBDIR/core.sh"
 
+declare -r MAIN_OPTIONS="
+HELP,h,help,,Show help info and exit
+GETVERSION,,version,,Output plowmod version information and exit
+VERBOSE,v,verbose,c|0|1|2|3|4=LEVEL,Verbosity level: 0=none, 1=err, 2=notice (default), 3=dbg, 4=report
+QUIET,q,quiet,,Alias for -v0
+NO_COLOR,,no-color,,Disables log notice & log error output coloring
+MOD_DIR,,modules-directory,D=DIR,For maintainers only. Set modules directory (default is ${PLOWSHARE_CONFDIR/#$HOME/\~}/modules.d)"
+
 # Process command-line (plowmod options).
 # Note: Ignore returned UNUSED_ARGS[@], it will be empty.
 eval "$(process_core_options 'plowmod' "$MAIN_OPTIONS$ACTION_OPTIONS" "$@")" || exit
@@ -332,6 +339,8 @@ elif [ -n "$DO_UPDATE" ]; then
         mod_update "$U" || RETVAL=$?
         RETVALS+=($RETVAL)
     done < <(find "$DDIR" -mindepth 2 -maxdepth 2 -name config)
+    test "$RETVAL" || \
+        log_notice "plowmod: no directory found, have you invoked \`plowmod --install' first?"
 fi
 
 if [ ${#RETVALS[@]} -eq 0 ]; then
